AlignmentValue

Struct AlignmentValue 

pub struct AlignmentValue(/* private fields */);
Helper type for alignment calculations

Implementations

Source

impl AlignmentValue

pub const fn new(val: u64) -> Self

pub const fn from_next_power_of_two_size(size: SizeValue) -> Self

Returns an alignment that is the smallest power of two greater than the passed in size

pub const fn get(&self) -> u64

pub const fn max<const N: usize>(input: [AlignmentValue; N]) -> AlignmentValue

Returns the max alignment from an array of alignments

pub const fn is_aligned(&self, n: u64) -> bool

Returns true if n is a multiple of this alignment

pub const fn padding_needed_for(&self, n: u64) -> u64

Returns the amount of padding needed so that n + padding will be a multiple of this alignment

pub const fn round_up(&self, n: u64) -> u64

Will round up the given n so that the returned value will be a multiple of this alignment

pub const fn round_up_size(&self, n: SizeValue) -> SizeValue

Will round up the given n so that the returned value will be a multiple of this alignment